@@ -3,7 +3,7 @@ import logging
 from .client import Client
 from .config import EnvConfig
 from .consts import Outcome, Analysis, Resolution
-from .results import Results
-from .test import Test
+from .report import Report
+from .result import Test
 
 logging.basicConfig(level=logging.INFO, format="%(message)s")
